@@ -1,23 +1,31 @@
 package WebService::Solr::Document;
 
-use Moose;
-
 use WebService::Solr::Field;
-require XML::Generator;
+use XML::Easy::Element;
+use XML::Easy::Content;
+use XML::Easy::Text ();
+use Scalar::Util 'blessed';
 
-has 'fields' => (
-    is         => 'rw',
-    isa        => 'ArrayRef[Object]',
-    default    => sub { [] },
-    auto_deref => 1
-);
-
-has 'boost' => ( is => 'rw', isa => 'Maybe[Num]' );
-
-sub BUILDARGS {
+sub new {
     my ( $class, @fields ) = @_;
 
-    return { fields => [ _parse_fields( @fields ) ] };
+    my $self = {
+        fields => [ _parse_fields( @fields ) ]
+    };
+
+    return bless $self, $class;
+}
+
+sub boost {
+    my $self = shift;
+    $self->{ boost } = $_[ 0 ] if @_;
+    return $self->{ boost };
+}
+
+sub fields {
+    my $self = shift;
+    $self->{ fields } = $_[ 0 ] if @_;
+    return wantarray ? @{ $self->{ fields } } : $self->{ fields };
 }
 
 sub add_fields {
@@ -65,17 +73,22 @@ sub values_for {
     return map { $_->value } grep { $_->name eq $key } $self->fields;
 }
 
-sub to_xml {
+sub to_element {
     my $self = shift;
-    my $gen = XML::Generator->new( ':std', escape => 'always,even-entities' );
     my %attr = ( $self->boost ? ( boost => $self->boost ) : () );
 
-    return $gen->doc( \%attr, map { $_->to_xml } $self->fields );
+    my @elements = map { ( '' => $_->to_element ) } $self->fields;
+
+    return XML::Easy::Element->new( 'doc', \%attr,
+        XML::Easy::Content->new( [ @elements, '' ] ),
+    );
 }
 
-no Moose;
+sub to_xml {
+    my $self = shift;
 
-__PACKAGE__->meta->make_immutable;
+    return XML::Easy::Text::xml10_write_element( $self->to_element );
+}
 
 1;
 
@@ -136,6 +149,10 @@ Returns the first value for C<$name>.
 
 Returns all values for C<$name>.
 
+=head2 to_element( )
+
+Serializes the object to an XML::Easy::Element object.
+
 =head2 to_xml( )
 
 Serializes the object to xml.
@@ -148,7 +165,7 @@ Kirk Beers
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2011 National Adult Literacy Database
+Copyright 2008-2012 National Adult Literacy Database
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
